Method: Rails::Queue::TestQueue#push

Defined in:
lib/rails/queue/queue.rb

#push(job) ⇒ Object

Marshal and unmarshal job before pushing it onto the queue. This will raise an exception on any attempts in tests to push jobs that can’t (or shouldn’t) be marshalled.



57
58
59
# File 'lib/rails/queue/queue.rb', line 57

def push(job)
  super Marshal.load(Marshal.dump(job))
end